<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl_BE">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX-gebruikersbeheerder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Beheer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Nieuwe gebruiker toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Gebruikersaccount toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Voer opnieuw het wachtwoord in voor de nieuwe gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>bevestig wachtwoord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <location filename="../mainwindow.ui" line="1201"/>
        <source>Username of new user</source>
        <translation>Gebruikersnaam van de nieuwe gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>User login name:</source>
        <translation>Gebruikers inlog naam:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="456"/>
        <location filename="../mainwindow.ui" line="1220"/>
        <source>Enter username of new user</source>
        <translation>Voer de gebruikersnaam in van de nieuwe gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>username</source>
        <translation>gebruikersnaam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Password for new user</source>
        <translation>Wachtwoord voor de nieuwe gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User password:</source>
        <translation>Gebruikerswachtwoord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Enter password for new user</source>
        <translation>Voer wachtwoord in voor de nieuwe gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>password</source>
        <translation>wachtwoord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Confirm user password:</source>
        <translation>Bevestig gebruikerswachtwoord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Delete User Account</source>
        <translation>Gebruikersaccount Verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Select user</source>
        <translation>Selecteer gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <location filename="../mainwindow.ui" line="1298"/>
        <location filename="../mainwindow.ui" line="1311"/>
        <location filename="../mainwindow.ui" line="1438"/>
        <location filename="../mainwindow.ui" line="1463"/>
        <source>Select user to delete</source>
        <translation>Selecteer de gebruiker die u wilt verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>User to delete:</source>
        <translation>Gebruiker die u wilt verwijderen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Verwijder ook de home-directory van de gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Delete user home directory</source>
        <translation>Verwijder home directory van de gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>Rename User Account</source>
        <translation>Hernoem Gebruikersaccount</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Select user to modify:</source>
        <translation>Selecteer gebruiker die u wilt aanpassen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>New user name:</source>
        <translation>Nieuwe gebruikersnaam:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Change User Password</source>
        <translation>Gebruikerswachtwoord Veranderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>new password</source>
        <translation>nieuw wachtwoord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Confirm new password:</source>
        <translation>Bevestig nieuw wachtwoord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>confirm new password</source>
        <translation>bevestig nieuw wachtwoord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>New user password:</source>
        <translation>Nieuw gebruikerswachtwoord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Repair a user configuration</source>
        <translation>Een gebruikersconfiguratie repareren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <location filename="../mainwindow.ui" line="1363"/>
        <source>Modify User Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Select user to repair</source>
        <translation>Selecteer een gebruiker voor reparatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="1447"/>
        <source>User to change:</source>
        <translation>Te wijzigen gebruiker:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Restore Defaults</source>
        <translation>Standaardinstellingen herstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="728"/>
        <source>Restore browser configs to MX defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Restore group memberships to MX defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Group memberships</source>
        <translation>Groepslidmaatschappen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Change Autologin Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>Log in automatically</source>
        <translation>Log automatisch in</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>Require password to log in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>Copy/Sync</source>
        <translation>Kopiëren/Synchroniseren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="818"/>
        <source>Copy Between Desktops</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <location filename="../mainwindow.ui" line="912"/>
        <source>Select desktop to copy from</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="858"/>
        <source>Select to only copy files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="861"/>
        <source>Copy only</source>
        <translation>Alleen kopiëren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="877"/>
        <location filename="../mainwindow.ui" line="890"/>
        <source>Select desktop to copy to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <source>Copy to:</source>
        <translation>Kopieer naar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="921"/>
        <source>Copy from:</source>
        <translation>Kopiëer van:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="934"/>
        <source>Select to copy and then delete differences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="937"/>
        <source>Sync</source>
        <translation>Synchroniseren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="983"/>
        <source>Select to copy/sync Shared</source>
        <translation>Kies om Gedeeld te kopiëren/synchroniseren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="986"/>
        <source>Shared folder</source>
        <translation>Gedeelde map</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="999"/>
        <source>Select to copy/sync entire home</source>
        <translation>Selecteer om home als geheel te kopiëren/synchroniseren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Entire home</source>
        <translation>Geheel home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1034"/>
        <source>Select to copy/sync Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1037"/>
        <source>Documents folder</source>
        <translation>Documenten map</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>What to copy/sync:</source>
        <translation>Wat moet er gekopiëerd/gesynchroniseerd worden:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Progress</source>
        <translation>Voortgang</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1090"/>
        <location filename="../mainwindow.ui" line="1106"/>
        <source>Status of the changes</source>
        <translation>Status van de veranderingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1109"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1125"/>
        <source>Progress of the changes</source>
        <translation>Voortgang van de veranderingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1162"/>
        <source>Add/Remove Groups</source>
        <translation>Groepen Toevoegen/Verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1174"/>
        <source>Add Group</source>
        <translation>Groep Toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1204"/>
        <source>Group name:</source>
        <translation>Groepsnaam:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1226"/>
        <source>groupname</source>
        <translation>groepsnaam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1258"/>
        <source>Delete Group</source>
        <translation>Groep Verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1320"/>
        <source>Group to delete:</source>
        <translation>Te verwijderen groep:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1351"/>
        <source>Group Membership</source>
        <translation>Groepslidmaatschap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1470"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1490"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Apply any changes</source>
        <translation>Veranderingen toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1553"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1560"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1567"/>
        <source>Cancel any changes then quit</source>
        <translation>Iedere verandering ongedaan maken, dan afsluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1570"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1577"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1618"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1621"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1628"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1635"/>
        <source>About this application</source>
        <translation>Over deze applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1638"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1645"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <location filename="../mainwindow.cpp" line="176"/>
        <location filename="../mainwindow.cpp" line="187"/>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="205"/>
        <location filename="../mainwindow.cpp" line="635"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <location filename="../mainwindow.cpp" line="687"/>
        <location filename="../mainwindow.cpp" line="695"/>
        <location filename="../mainwindow.cpp" line="826"/>
        <location filename="../mainwindow.cpp" line="930"/>
        <location filename="../mainwindow.cpp" line="936"/>
        <location filename="../mainwindow.cpp" line="941"/>
        <location filename="../mainwindow.cpp" line="946"/>
        <location filename="../mainwindow.cpp" line="951"/>
        <source>none</source>
        <translation>geen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>browse...</source>
        <translation>navigeer...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>Mozilla settings were reset.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>Autologin options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Synchronizing desktop...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Copying desktop...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Password entries do not match. Please try again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>The user was added ok.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Failed to add the user.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Password successfully changed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>Failed to change password.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="397"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>The user has been deleted.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Failed to delete the user.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>The system group was added ok.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="443"/>
        <source>Failed to add the system group.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>The group has been deleted.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Failed to delete the group.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>The changes have been applied.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Failed to apply group changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>The selected user name is currently in use.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>The user was renamed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Synchronizing desktop...ok</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="549"/>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Copying desktop...ok</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Synchronizing desktop...failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Copying desktop...failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Confirmation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="600"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="790"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="791"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Simple user configuration for MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="794"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="795"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>Select folder to copy to</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
</context>
</TS>